package com.zdqz.data.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.data.domain.DataDljy;
import com.zdqz.data.service.IDataDljyService;
import com.zdqz.common.utils.poi.ExcelUtil;
import com.zdqz.common.core.page.TableDataInfo;

/**
 * 毒力基因耐药药品、敏感药品管理Controller
 * 
 * @author 攻心小虫
 * @date 2025-06-03
 */
@RestController
@RequestMapping("/data/dljy")
public class DataDljyController extends BaseController
{
    @Autowired
    private IDataDljyService dataDljyService;

    /**
     * 查询毒力基因耐药药品、敏感药品管理列表
     */
    @PreAuthorize("@ss.hasPermi('data:dljy:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataDljy dataDljy)
    {
        startPage();
        List<DataDljy> list = dataDljyService.selectDataDljyList(dataDljy);
        return getDataTable(list);
    }

    /**
     * 导出毒力基因耐药药品、敏感药品管理列表
     */
    @PreAuthorize("@ss.hasPermi('data:dljy:export')")
    @Log(title = "毒力基因耐药药品、敏感药品管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataDljy dataDljy)
    {
        List<DataDljy> list = dataDljyService.selectDataDljyList(dataDljy);
        ExcelUtil<DataDljy> util = new ExcelUtil<DataDljy>(DataDljy.class);
        util.exportExcel(response, list, "毒力基因耐药药品、敏感药品管理数据");
    }

    /**
     * 获取毒力基因耐药药品、敏感药品管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('data:dljy:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dataDljyService.selectDataDljyById(id));
    }

    /**
     * 新增毒力基因耐药药品、敏感药品管理
     */
    @PreAuthorize("@ss.hasPermi('data:dljy:add')")
    @Log(title = "毒力基因耐药药品、敏感药品管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataDljy dataDljy)
    {
        return toAjax(dataDljyService.insertDataDljy(dataDljy));
    }

    /**
     * 修改毒力基因耐药药品、敏感药品管理
     */
    @PreAuthorize("@ss.hasPermi('data:dljy:edit')")
    @Log(title = "毒力基因耐药药品、敏感药品管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataDljy dataDljy)
    {
        return toAjax(dataDljyService.updateDataDljy(dataDljy));
    }

    /**
     * 删除毒力基因耐药药品、敏感药品管理
     */
    @PreAuthorize("@ss.hasPermi('data:dljy:remove')")
    @Log(title = "毒力基因耐药药品、敏感药品管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dataDljyService.deleteDataDljyByIds(ids));
    }
}
