package com.zdqz.data.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.data.domain.DataNyjy;
import com.zdqz.data.service.IDataNyjyService;
import com.zdqz.common.utils.poi.ExcelUtil;
import com.zdqz.common.core.page.TableDataInfo;

/**
 * 耐药基因耐药药品、敏感药品管理Controller
 * 
 * @author 攻心小虫
 * @date 2025-06-03
 */
@RestController
@RequestMapping("/data/nyjy")
public class DataNyjyController extends BaseController
{
    @Autowired
    private IDataNyjyService dataNyjyService;

    /**
     * 查询耐药基因耐药药品、敏感药品管理列表
     */
    @PreAuthorize("@ss.hasPermi('data:nyjy:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataNyjy dataNyjy)
    {
        startPage();
        List<DataNyjy> list = dataNyjyService.selectDataNyjyList(dataNyjy);
        return getDataTable(list);
    }

    /**
     * 导出耐药基因耐药药品、敏感药品管理列表
     */
    @PreAuthorize("@ss.hasPermi('data:nyjy:export')")
    @Log(title = "耐药基因耐药药品、敏感药品管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataNyjy dataNyjy)
    {
        List<DataNyjy> list = dataNyjyService.selectDataNyjyList(dataNyjy);
        ExcelUtil<DataNyjy> util = new ExcelUtil<DataNyjy>(DataNyjy.class);
        util.exportExcel(response, list, "耐药基因耐药药品、敏感药品管理数据");
    }

    /**
     * 获取耐药基因耐药药品、敏感药品管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('data:nyjy:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dataNyjyService.selectDataNyjyById(id));
    }

    /**
     * 新增耐药基因耐药药品、敏感药品管理
     */
    @PreAuthorize("@ss.hasPermi('data:nyjy:add')")
    @Log(title = "耐药基因耐药药品、敏感药品管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataNyjy dataNyjy)
    {
        return toAjax(dataNyjyService.insertDataNyjy(dataNyjy));
    }

    /**
     * 修改耐药基因耐药药品、敏感药品管理
     */
    @PreAuthorize("@ss.hasPermi('data:nyjy:edit')")
    @Log(title = "耐药基因耐药药品、敏感药品管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataNyjy dataNyjy)
    {
        return toAjax(dataNyjyService.updateDataNyjy(dataNyjy));
    }

    /**
     * 删除耐药基因耐药药品、敏感药品管理
     */
    @PreAuthorize("@ss.hasPermi('data:nyjy:remove')")
    @Log(title = "耐药基因耐药药品、敏感药品管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dataNyjyService.deleteDataNyjyByIds(ids));
    }
}
