package com.zdqz.sample.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.sample.domain.SampleHospital;
import com.zdqz.sample.service.ISampleHospitalService;
import com.zdqz.common.utils.poi.ExcelUtil;
import com.zdqz.common.core.page.TableDataInfo;

/**
 * 送检医院Controller
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@RestController
@RequestMapping("/sample/sampleHospital")
public class SampleHospitalController extends BaseController
{
    @Autowired
    private ISampleHospitalService sampleHospitalService;

    /**
     * 查询送检医院列表
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleHospital:list')")
    @GetMapping("/list")
    public TableDataInfo list(SampleHospital sampleHospital)
    {
        startPage();
        List<SampleHospital> list = sampleHospitalService.selectSampleHospitalList(sampleHospital);
        return getDataTable(list);
    }

    /**
     * 导出送检医院列表
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleHospital:export')")
    @Log(title = "送检医院", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SampleHospital sampleHospital)
    {
        List<SampleHospital> list = sampleHospitalService.selectSampleHospitalList(sampleHospital);
        ExcelUtil<SampleHospital> util = new ExcelUtil<SampleHospital>(SampleHospital.class);
        util.exportExcel(response, list, "送检医院数据");
    }

    /**
     * 获取送检医院详细信息
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleHospital:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sampleHospitalService.selectSampleHospitalById(id));
    }

    /**
     * 新增送检医院
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleHospital:add')")
    @Log(title = "送检医院", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SampleHospital sampleHospital)
    {
        return toAjax(sampleHospitalService.insertSampleHospital(sampleHospital));
    }

    /**
     * 修改送检医院
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleHospital:edit')")
    @Log(title = "送检医院", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SampleHospital sampleHospital)
    {
        return toAjax(sampleHospitalService.updateSampleHospital(sampleHospital));
    }

    /**
     * 删除送检医院
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleHospital:remove')")
    @Log(title = "送检医院", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sampleHospitalService.deleteSampleHospitalByIds(ids));
    }
}
