package com.zdqz.sample.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.sample.domain.SampleInfo;
import com.zdqz.sample.service.ISampleInfoService;
import com.zdqz.common.utils.poi.ExcelUtil;
import com.zdqz.common.core.page.TableDataInfo;

/**
 * 样品管理Controller
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@RestController
@RequestMapping("/sample/sampleInfo")
public class SampleInfoController extends BaseController
{
    @Autowired
    private ISampleInfoService sampleInfoService;

    /**
     * 查询样品管理列表
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(SampleInfo sampleInfo)
    {
        startPage();
        List<SampleInfo> list = sampleInfoService.selectSampleInfoList(sampleInfo);
        return getDataTable(list);
    }

    /**
     * 导出样品管理列表
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleInfo:export')")
    @Log(title = "样品管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SampleInfo sampleInfo)
    {
        List<SampleInfo> list = sampleInfoService.selectSampleInfoList(sampleInfo);
        ExcelUtil<SampleInfo> util = new ExcelUtil<SampleInfo>(SampleInfo.class);
        util.exportExcel(response, list, "样品管理数据");
    }

    /**
     * 获取样品管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleInfo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sampleInfoService.selectSampleInfoById(id));
    }

    /**
     * 新增样品管理
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleInfo:add')")
    @Log(title = "样品管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SampleInfo sampleInfo)
    {
        return toAjax(sampleInfoService.insertSampleInfo(sampleInfo));
    }

    /**
     * 修改样品管理
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleInfo:edit')")
    @Log(title = "样品管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SampleInfo sampleInfo)
    {
        return toAjax(sampleInfoService.updateSampleInfo(sampleInfo));
    }

    /**
     * 删除样品管理
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleInfo:remove')")
    @Log(title = "样品管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sampleInfoService.deleteSampleInfoByIds(ids));
    }
}
