package com.zdqz.sample.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.sample.domain.SamplePatient;
import com.zdqz.sample.service.ISamplePatientService;
import com.zdqz.common.utils.poi.ExcelUtil;
import com.zdqz.common.core.page.TableDataInfo;

/**
 * 样品患者信息Controller
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@RestController
@RequestMapping("/sample/samplePatient")
public class SamplePatientController extends BaseController
{
    @Autowired
    private ISamplePatientService samplePatientService;

    /**
     * 查询样品患者信息列表
     */
    @PreAuthorize("@ss.hasPermi('sample:samplePatient:list')")
    @GetMapping("/list")
    public TableDataInfo list(SamplePatient samplePatient)
    {
        startPage();
        List<SamplePatient> list = samplePatientService.selectSamplePatientList(samplePatient);
        return getDataTable(list);
    }

    /**
     * 导出样品患者信息列表
     */
    @PreAuthorize("@ss.hasPermi('sample:samplePatient:export')")
    @Log(title = "样品患者信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SamplePatient samplePatient)
    {
        List<SamplePatient> list = samplePatientService.selectSamplePatientList(samplePatient);
        ExcelUtil<SamplePatient> util = new ExcelUtil<SamplePatient>(SamplePatient.class);
        util.exportExcel(response, list, "样品患者信息数据");
    }

    /**
     * 获取样品患者信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('sample:samplePatient:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(samplePatientService.selectSamplePatientById(id));
    }

    /**
     * 新增样品患者信息
     */
    @PreAuthorize("@ss.hasPermi('sample:samplePatient:add')")
    @Log(title = "样品患者信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SamplePatient samplePatient)
    {
        return toAjax(samplePatientService.insertSamplePatient(samplePatient));
    }

    /**
     * 修改样品患者信息
     */
    @PreAuthorize("@ss.hasPermi('sample:samplePatient:edit')")
    @Log(title = "样品患者信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SamplePatient samplePatient)
    {
        return toAjax(samplePatientService.updateSamplePatient(samplePatient));
    }

    /**
     * 删除样品患者信息
     */
    @PreAuthorize("@ss.hasPermi('sample:samplePatient:remove')")
    @Log(title = "样品患者信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(samplePatientService.deleteSamplePatientByIds(ids));
    }
}
