package com.zdqz.sample.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.sample.domain.SampleType;
import com.zdqz.sample.service.ISampleTypeService;
import com.zdqz.common.utils.poi.ExcelUtil;
import com.zdqz.common.core.page.TableDataInfo;

/**
 * 样本类型Controller
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@RestController
@RequestMapping("/sample/sampleType")
public class SampleTypeController extends BaseController
{
    @Autowired
    private ISampleTypeService sampleTypeService;

    /**
     * 查询样本类型列表
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleType:list')")
    @GetMapping("/list")
    public TableDataInfo list(SampleType sampleType)
    {
        startPage();
        List<SampleType> list = sampleTypeService.selectSampleTypeList(sampleType);
        return getDataTable(list);
    }

    /**
     * 导出样本类型列表
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleType:export')")
    @Log(title = "样本类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SampleType sampleType)
    {
        List<SampleType> list = sampleTypeService.selectSampleTypeList(sampleType);
        ExcelUtil<SampleType> util = new ExcelUtil<SampleType>(SampleType.class);
        util.exportExcel(response, list, "样本类型数据");
    }

    /**
     * 获取样本类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleType:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sampleTypeService.selectSampleTypeById(id));
    }

    /**
     * 新增样本类型
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleType:add')")
    @Log(title = "样本类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SampleType sampleType)
    {
        return toAjax(sampleTypeService.insertSampleType(sampleType));
    }

    /**
     * 修改样本类型
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleType:edit')")
    @Log(title = "样本类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SampleType sampleType)
    {
        return toAjax(sampleTypeService.updateSampleType(sampleType));
    }

    /**
     * 删除样本类型
     */
    @PreAuthorize("@ss.hasPermi('sample:sampleType:remove')")
    @Log(title = "样本类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sampleTypeService.deleteSampleTypeByIds(ids));
    }
}
