package com.zdqz.sample.service.impl;

import java.util.List;
import com.zdqz.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zdqz.sample.mapper.SampleDeptMapper;
import com.zdqz.sample.domain.SampleDept;
import com.zdqz.sample.service.ISampleDeptService;

/**
 * 送检科室Service业务层处理
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@Service
public class SampleDeptServiceImpl implements ISampleDeptService 
{
    @Autowired
    private SampleDeptMapper sampleDeptMapper;

    /**
     * 查询送检科室
     * 
     * @param id 送检科室主键
     * @return 送检科室
     */
    @Override
    public SampleDept selectSampleDeptById(Long id)
    {
        return sampleDeptMapper.selectSampleDeptById(id);
    }

    /**
     * 查询送检科室列表
     * 
     * @param sampleDept 送检科室
     * @return 送检科室
     */
    @Override
    public List<SampleDept> selectSampleDeptList(SampleDept sampleDept)
    {
        return sampleDeptMapper.selectSampleDeptList(sampleDept);
    }

    /**
     * 新增送检科室
     * 
     * @param sampleDept 送检科室
     * @return 结果
     */
    @Override
    public int insertSampleDept(SampleDept sampleDept)
    {
        sampleDept.setCreateTime(DateUtils.getNowDate());
        return sampleDeptMapper.insertSampleDept(sampleDept);
    }

    /**
     * 修改送检科室
     * 
     * @param sampleDept 送检科室
     * @return 结果
     */
    @Override
    public int updateSampleDept(SampleDept sampleDept)
    {
        sampleDept.setUpdateTime(DateUtils.getNowDate());
        return sampleDeptMapper.updateSampleDept(sampleDept);
    }

    /**
     * 批量删除送检科室
     * 
     * @param ids 需要删除的送检科室主键
     * @return 结果
     */
    @Override
    public int deleteSampleDeptByIds(Long[] ids)
    {
        return sampleDeptMapper.deleteSampleDeptByIds(ids);
    }

    /**
     * 删除送检科室信息
     * 
     * @param id 送检科室主键
     * @return 结果
     */
    @Override
    public int deleteSampleDeptById(Long id)
    {
        return sampleDeptMapper.deleteSampleDeptById(id);
    }
}
