package com.zdqz.sample.service.impl;

import java.util.List;
import com.zdqz.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zdqz.sample.mapper.SampleHospitalMapper;
import com.zdqz.sample.domain.SampleHospital;
import com.zdqz.sample.service.ISampleHospitalService;

/**
 * 送检医院Service业务层处理
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@Service
public class SampleHospitalServiceImpl implements ISampleHospitalService 
{
    @Autowired
    private SampleHospitalMapper sampleHospitalMapper;

    /**
     * 查询送检医院
     * 
     * @param id 送检医院主键
     * @return 送检医院
     */
    @Override
    public SampleHospital selectSampleHospitalById(Long id)
    {
        return sampleHospitalMapper.selectSampleHospitalById(id);
    }

    /**
     * 查询送检医院列表
     * 
     * @param sampleHospital 送检医院
     * @return 送检医院
     */
    @Override
    public List<SampleHospital> selectSampleHospitalList(SampleHospital sampleHospital)
    {
        return sampleHospitalMapper.selectSampleHospitalList(sampleHospital);
    }

    /**
     * 新增送检医院
     * 
     * @param sampleHospital 送检医院
     * @return 结果
     */
    @Override
    public int insertSampleHospital(SampleHospital sampleHospital)
    {
        sampleHospital.setCreateTime(DateUtils.getNowDate());
        return sampleHospitalMapper.insertSampleHospital(sampleHospital);
    }

    /**
     * 修改送检医院
     * 
     * @param sampleHospital 送检医院
     * @return 结果
     */
    @Override
    public int updateSampleHospital(SampleHospital sampleHospital)
    {
        sampleHospital.setUpdateTime(DateUtils.getNowDate());
        return sampleHospitalMapper.updateSampleHospital(sampleHospital);
    }

    /**
     * 批量删除送检医院
     * 
     * @param ids 需要删除的送检医院主键
     * @return 结果
     */
    @Override
    public int deleteSampleHospitalByIds(Long[] ids)
    {
        return sampleHospitalMapper.deleteSampleHospitalByIds(ids);
    }

    /**
     * 删除送检医院信息
     * 
     * @param id 送检医院主键
     * @return 结果
     */
    @Override
    public int deleteSampleHospitalById(Long id)
    {
        return sampleHospitalMapper.deleteSampleHospitalById(id);
    }
}
