package com.zdqz.sample.service.impl;

import java.util.List;
import com.zdqz.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zdqz.sample.mapper.SampleInfoMapper;
import com.zdqz.sample.domain.SampleInfo;
import com.zdqz.sample.service.ISampleInfoService;

/**
 * 样品管理Service业务层处理
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@Service
public class SampleInfoServiceImpl implements ISampleInfoService 
{
    @Autowired
    private SampleInfoMapper sampleInfoMapper;

    /**
     * 查询样品管理
     * 
     * @param id 样品管理主键
     * @return 样品管理
     */
    @Override
    public SampleInfo selectSampleInfoById(Long id)
    {
        return sampleInfoMapper.selectSampleInfoById(id);
    }

    /**
     * 查询样品管理列表
     * 
     * @param sampleInfo 样品管理
     * @return 样品管理
     */
    @Override
    public List<SampleInfo> selectSampleInfoList(SampleInfo sampleInfo)
    {
        return sampleInfoMapper.selectSampleInfoList(sampleInfo);
    }

    /**
     * 新增样品管理
     * 
     * @param sampleInfo 样品管理
     * @return 结果
     */
    @Override
    public int insertSampleInfo(SampleInfo sampleInfo)
    {
        sampleInfo.setCreateTime(DateUtils.getNowDate());
        return sampleInfoMapper.insertSampleInfo(sampleInfo);
    }

    /**
     * 修改样品管理
     * 
     * @param sampleInfo 样品管理
     * @return 结果
     */
    @Override
    public int updateSampleInfo(SampleInfo sampleInfo)
    {
        sampleInfo.setUpdateTime(DateUtils.getNowDate());
        return sampleInfoMapper.updateSampleInfo(sampleInfo);
    }

    /**
     * 批量删除样品管理
     * 
     * @param ids 需要删除的样品管理主键
     * @return 结果
     */
    @Override
    public int deleteSampleInfoByIds(Long[] ids)
    {
        return sampleInfoMapper.deleteSampleInfoByIds(ids);
    }

    /**
     * 删除样品管理信息
     * 
     * @param id 样品管理主键
     * @return 结果
     */
    @Override
    public int deleteSampleInfoById(Long id)
    {
        return sampleInfoMapper.deleteSampleInfoById(id);
    }
}
