package com.zdqz.sample.service.impl;

import java.util.List;
import com.zdqz.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zdqz.sample.mapper.SamplePatientMapper;
import com.zdqz.sample.domain.SamplePatient;
import com.zdqz.sample.service.ISamplePatientService;

/**
 * 样品患者信息Service业务层处理
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@Service
public class SamplePatientServiceImpl implements ISamplePatientService 
{
    @Autowired
    private SamplePatientMapper samplePatientMapper;

    /**
     * 查询样品患者信息
     * 
     * @param id 样品患者信息主键
     * @return 样品患者信息
     */
    @Override
    public SamplePatient selectSamplePatientById(Long id)
    {
        return samplePatientMapper.selectSamplePatientById(id);
    }

    /**
     * 查询样品患者信息列表
     * 
     * @param samplePatient 样品患者信息
     * @return 样品患者信息
     */
    @Override
    public List<SamplePatient> selectSamplePatientList(SamplePatient samplePatient)
    {
        return samplePatientMapper.selectSamplePatientList(samplePatient);
    }

    /**
     * 新增样品患者信息
     * 
     * @param samplePatient 样品患者信息
     * @return 结果
     */
    @Override
    public int insertSamplePatient(SamplePatient samplePatient)
    {
        samplePatient.setCreateTime(DateUtils.getNowDate());
        return samplePatientMapper.insertSamplePatient(samplePatient);
    }

    /**
     * 修改样品患者信息
     * 
     * @param samplePatient 样品患者信息
     * @return 结果
     */
    @Override
    public int updateSamplePatient(SamplePatient samplePatient)
    {
        samplePatient.setUpdateTime(DateUtils.getNowDate());
        return samplePatientMapper.updateSamplePatient(samplePatient);
    }

    /**
     * 批量删除样品患者信息
     * 
     * @param ids 需要删除的样品患者信息主键
     * @return 结果
     */
    @Override
    public int deleteSamplePatientByIds(Long[] ids)
    {
        return samplePatientMapper.deleteSamplePatientByIds(ids);
    }

    /**
     * 删除样品患者信息信息
     * 
     * @param id 样品患者信息主键
     * @return 结果
     */
    @Override
    public int deleteSamplePatientById(Long id)
    {
        return samplePatientMapper.deleteSamplePatientById(id);
    }
}
