package com.zdqz.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.system.domain.SysCnarea;
import com.zdqz.system.service.ISysCnareaService;
import com.zdqz.common.utils.poi.ExcelUtil;
import com.zdqz.common.core.page.TableDataInfo;

/**
 * 中国行政区域Controller
 * 
 * @author 攻心小虫
 * @date 2025-06-03
 */
@RestController
@RequestMapping("/system/cnarea")
public class SysCnareaController extends BaseController
{
    @Autowired
    private ISysCnareaService sysCnareaService;

    /**
     * 查询中国行政区域列表
     */
    @PreAuthorize("@ss.hasPermi('system:cnarea:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysCnarea sysCnarea)
    {
        startPage();
        List<SysCnarea> list = sysCnareaService.selectSysCnareaList(sysCnarea);
        return getDataTable(list);
    }

    /**
     * 导出中国行政区域列表
     */
    @PreAuthorize("@ss.hasPermi('system:cnarea:export')")
    @Log(title = "中国行政区域", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysCnarea sysCnarea)
    {
        List<SysCnarea> list = sysCnareaService.selectSysCnareaList(sysCnarea);
        ExcelUtil<SysCnarea> util = new ExcelUtil<SysCnarea>(SysCnarea.class);
        util.exportExcel(response, list, "中国行政区域数据");
    }

    /**
     * 获取中国行政区域详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:cnarea:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(sysCnareaService.selectSysCnareaById(id));
    }

    /**
     * 新增中国行政区域
     */
    @PreAuthorize("@ss.hasPermi('system:cnarea:add')")
    @Log(title = "中国行政区域", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysCnarea sysCnarea)
    {
        return toAjax(sysCnareaService.insertSysCnarea(sysCnarea));
    }

    /**
     * 修改中国行政区域
     */
    @PreAuthorize("@ss.hasPermi('system:cnarea:edit')")
    @Log(title = "中国行政区域", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysCnarea sysCnarea)
    {
        return toAjax(sysCnareaService.updateSysCnarea(sysCnarea));
    }

    /**
     * 删除中国行政区域
     */
    @PreAuthorize("@ss.hasPermi('system:cnarea:remove')")
    @Log(title = "中国行政区域", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(sysCnareaService.deleteSysCnareaByIds(ids));
    }
}
